==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/ro_ro/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s jurnalele Cron vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s jurnalele de tranzacții vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s jurnalele de service vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s jurnalele vechi de setare a clientului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s jurnalele vechi ale utilizatorului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s jurnalele vechi ale Messenger au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s jurnalele vechi de e-mail au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s jurnalele de contact vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s jurnalele vechi de acces la cont au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s jurnalele vechi ale modulului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s jurnalele vechi ale Gateway au fost șterse.';
$lang['Automation.task.cleanup_logs.completed'] = 'Sarcina de curățare a jurnalelor s-a încheiat.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Încercarea de a curăța jurnalele vechi.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/ro_ro/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s jurnalele Cron vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s jurnalele de tranzacții vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s jurnalele de service vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s jurnalele vechi de setare a clientului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s jurnalele vechi ale utilizatorului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s jurnalele vechi ale Messenger au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s jurnalele vechi de e-mail au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s jurnalele de contact vechi au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s jurnalele vechi de acces la cont au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s jurnalele vechi ale modulului au fost șterse.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s jurnalele vechi ale Gateway au fost șterse.';
$lang['Automation.task.cleanup_logs.completed'] = 'Sarcina de curățare a jurnalelor s-a încheiat.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Încercarea de a curăța jurnalele vechi.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s vechile jurnale Service Changes au fost șterse.';
